@@ -4,9 +4,11 @@ This module allows users to execute funtioncs in signal_transmitter, while provi
 
 
 import numpy as np
-#import signal_transmitter as st
-from . import signal_transmitter as st
-from .DESHIMA.MKID import filterbank as ft
+import signal_transmitter as st
+import DESHIMA.MKID.filterbank as ft
+
+#from . import signal_transmitter as st
+#from .DESHIMA.MKID import filterbank as ft
 import os
 
 def calcMaxObsTime(dictionary):
@@ -22,23 +24,6 @@ def calcMaxObsTime(dictionary):
                     /dictionary['windspeed']
     return max_obs_time
 
-def change_pwv_0(dictionary):
-    """
-    Parameters
-    ----------
-    dictionary : dict
-        Dictionary obtained from get_dictionary() with the same keywords as run_tiempo() executed after this function. 
-
-    Returns
-    -------
-    None.
-    
-    Must be executed before changing the pwv value. Input is a dictionary from get_dictionary
-    """
-    st1 = st.signal_transmitter(dictionary)
-    st1.save_filtered_pwv_map()
-    return
-
 def new_filterbank(dictionary):
     """
     Parameters
